==> Iuno-3.16.19.13360.tar.gz: Iuno-3.16.19.13360/Iuno/template_editor/__init__.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
# $Id: __init__.py 11724 2019-09-24 07:05:18Z Lavender $
#
# Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
#
# Licensed under the Proprietary License,
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at our web site.
#
# See the License for the specific language governing permissions and
# limitations under the License.
#
# $Author: Lavender $ (last)
# $Date: 2019-09-24 15:05:18 +0800 (Tue, 24 Sep 2019) $
# $Revision: 11724 $

import os

from django.conf import settings

# FIXME: 看 Iuno 該怎麼設定
STATIC_DIR = None
if not settings.DEBUG:
    if hasattr(settings, "STATIC_ROOT"):
        STATIC_DIR = settings.STATIC_ROOT
else:
    if hasattr(settings, "STATICFILES_DIRS"):
        try:
            STATIC_DIR = settings.STATICFILES_DIRS[0]
        except Exception as e:
            pass
        
if not STATIC_DIR:
    STATIC_DIR = os.path.join(settings.BASE_DIR, "static")

TEMPLATE_DIR = None
if hasattr(settings, "TEMPLATES"):
    try:
        TEMPLATE_DIR = settings.TEMPLATES[0]['DIRS'][0]
    except Exception as e:
        pass

if not TEMPLATE_DIR:
    TEMPLATE_DIR = os.path.join(settings.BASE_DIR, "templates")

BACKUP_DIR_NAME = "_Iuno.template_editor_backup" 

BACKUP_FILE_DIR = os.path.join(
    STATIC_DIR, BACKUP_DIR_NAME)

if not os.path.isdir(BACKUP_FILE_DIR):
    os.mkdir(BACKUP_FILE_DIR)

import six

def toBytes(s):
    return s if six.PY2 else s.encode()

==> Iuno-4.0.2.13368.tar.gz: Iuno-4.0.2.13368/Iuno/template_editor/__init__.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
# $Id: __init__.py 13368 2022-01-01 08:52:58Z Lavender $
#
# Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
#
# Licensed under the Proprietary License,
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at our web site.
#
# See the License for the specific language governing permissions and
# limitations under the License.
#
# $Author: Lavender $ (last)
# $Date: 2022-01-01 16:52:58 +0800 (週六, 01 一月 2022) $
# $Revision: 13368 $

import os

from django.conf import settings

# FIXME: 看 Iuno 該怎麼設定
STATIC_DIR = None
if not settings.DEBUG:
    if hasattr(settings, "STATIC_ROOT"):
        STATIC_DIR = settings.STATIC_ROOT
else:
    if hasattr(settings, "STATICFILES_DIRS"):
        try:
            STATIC_DIR = settings.STATICFILES_DIRS[0]
        except Exception as e:
            pass
        
if not STATIC_DIR:
    STATIC_DIR = os.path.join(settings.BASE_DIR, "static")

if not hasattr(settings, "TEMPLATE_EDITOR_TEMPLATE_DIR"):
    # 找尋 settings.py 的 TEMPLATES 內的設定當 TEMPLATE_DIR
    TEMPLATE_DIR = None
    if hasattr(settings, "TEMPLATES"):
        try:
            TEMPLATE_DIR = settings.TEMPLATES[0]['DIRS'][0]
        except Exception as e:
            pass

    if not TEMPLATE_DIR:
        TEMPLATE_DIR = os.path.join(settings.BASE_DIR, "templates")
else:
    TEMPLATE_DIR = settings.TEMPLATE_EDITOR_TEMPLATE_DIR

BACKUP_DIR_NAME = "_Iuno.template_editor_backup" 

BACKUP_FILE_DIR = os.path.join(
    STATIC_DIR, BACKUP_DIR_NAME)

if not os.path.isdir(BACKUP_FILE_DIR):
    os.mkdir(BACKUP_FILE_DIR)

import six

def toBytes(s):
    return s if six.PY2 else s.encode()
